@@ -1,5 +1,6 @@
 #include <qapp.h>
 
+#include <qdialog.h>
 #include <qlabel.h>
 #include <qlined.h>
 #include <qpushbt.h>
@@ -83,11 +84,11 @@ private:
     QRect     eraseRect;               // covers last displayed text/image
 };
 
-class FontSelect : public QWidget
+class FontSelect : public QDialog
 {
     Q_OBJECT
 public:
-    FontSelect( QWidget *parent=0, const char *name=0 );
+    FontSelect( QView *parent=0, const char *name=0 );
 private slots:
     void	 newStrikeOut();
     void	 doFont();
@@ -208,6 +209,7 @@ void XFormControl::newMtx()
     emit newMatrix( m );
 }
 
+    
 void XFormControl::selectFont()
 {
     if (!fs) {
@@ -274,7 +276,7 @@ const int yOff = 35;
 ShowXForm::ShowXForm( QWidget *parent, const char *name )
 	: QWidget( parent, name )
 {
-    setFont( QFont( "helvetica", 32 ) );
+    setFont( QFont( "Charter", 48, QFont::Bold ) );
     setBackgroundColor( white );
     usingImage = FALSE;
 }
@@ -328,12 +330,13 @@ void ShowXForm::showIt()
     Q2DMatrix m;  // copy user specified transform
     QFontMetrics fm( font() ); // metrics for widget font
     int textYPos = 0; // distance from boundingRect y pos to baseline
-
+    int textXPos = 0; // distance from boundingRect x pos to text start
     if ( imageMode() ) {
         rect = img.rect();
     } else {
         rect     = fm.boundingRect( text );   // rectangle covering text
         textYPos = -rect.y();
+        textXPos = -rect.x();
     }
     rect.setTopLeft( QPoint( -rect.width()/2, -rect.height()/2 ) );
           // compute union of new and old rect 
@@ -352,17 +355,18 @@ void ShowXForm::showIt()
     if ( imageMode() )
         p.drawPixmap( rect.topLeft(), img );
     else
-        p.drawText( rect.left(), rect.top() + textYPos, text );
+        p.drawText( rect.left() + textXPos, rect.top() + textYPos, text );
     p.end();
-    bitBlt( this, width()/2-eraseRect.width()/2,  // copy pixmap to widget
-                  height()/2-eraseRect.height()/2,
-                  &pix, 0, 0, -1, -1 );
+    int xpos = width()/2  - eraseRect.width()/2;
+    int ypos = height()/2 - eraseRect.height()/2;
+    bitBlt( this, xpos, ypos,			// copy pixmap to widget
+	    &pix, 0, 0, -1, -1 );
     eraseRect =  mtx.boundingRect( rect );
     return;
 }
 
-FontSelect::FontSelect( QWidget *parent, const char *name)
-	: QWidget( parent, name ), f( "Helvetica", 32 )
+FontSelect::FontSelect( QView *parent, const char *name)
+    : QDialog( parent, name, 0 ), f( "Charter", 48, QFont::Bold )
 {
     const char *radios[] = { "Light (25)", "Normal (50)", "DemiBold (63)", 
                              "Bold (75)", "Black (87)" };
@@ -386,14 +390,14 @@ FontSelect::FontSelect( QWidget *parent, const char *name)
     sizeL->setText( "Point size :" );
 	    
     family->setGeometry( 110, yOff + 10, 100, 20 );
-    family->setText( "Helvetica" );
+    family->setText( "Charter" );
 
     sizeE->setGeometry( 110, yOff + 40, 100, 20 );
-    sizeE->setText( "32" );
+    sizeE->setText( "48" );
 	    
     sizeS->setGeometry( 220, yOff + 40, 100, 20 );
     sizeS->setRange( 1, 100 );
-    sizeS->setValue( 32 );
+    sizeS->setValue( 48 );
     sizeS->setTracking( FALSE );
     connect( sizeS, SIGNAL(valueChanged(long)), SLOT(newSize(long)) );
     connect( sizeS, SIGNAL(sliderMoved(long)), SLOT(slidingSize(long)) );
@@ -412,12 +416,11 @@ FontSelect::FontSelect( QWidget *parent, const char *name)
 	    
     apply->setGeometry( 235, yOff + 10, 70, 20);
     apply->setText( "APPLY" );
+    apply->setDefault( TRUE );
     connect( apply, SIGNAL(clicked()), SLOT(doApply()) );
 
-    weight = new QButtonGroup( this, "weightGroupBox" );
+    weight = new QButtonGroup( "Weight", this, "weightGroupBox" );
     weight->setGeometry( 10, yOff + 100, 120, 120 );
-    weight->setTitle( "Weight" );
-    weight->setFrameStyle( QFrame::Plain | QFrame::Box );
     connect( weight, SIGNAL(clicked(int)), SLOT(newWeight(int)) );
     QString name;
     for( i = 0 ; i < 5 ; i++ ) {
@@ -426,7 +429,7 @@ FontSelect::FontSelect( QWidget *parent, const char *name)
 	rb[i]->setGeometry( 10, 15+i*20 , 95, 20 );
 	rb[i]->setText( radios[i] );
     }
-    rb[1]->setChecked( TRUE );
+    rb[3]->setChecked( TRUE );
 
     const char *familys[] = { "Charter", "Clean", "Courier", "Fixed",
 			    "Gothic", "Helvetica", "Lucida", "Lucidabright",
@@ -434,7 +437,7 @@ FontSelect::FontSelect( QWidget *parent, const char *name)
 			    "New century Schoolbook", 
 			    "Symbol", "Terminal", "Times", "Utopia", 0 };
 
-    const char *pSizes[]  = {  "8", "10", "12", "14", "18", "24", "32",
+    const char *pSizes[]  = {  "8", "10", "12", "14", "18", "24", "36",
 			    "48", "72", "96", 0 };
 
 
@@ -469,7 +472,6 @@ FontSelect::FontSelect( QWidget *parent, const char *name)
 
     mGroup = new QButtonGroup( this, "metricsGroupBox" );
     mGroup->setTitle( "Actual font" );
-    mGroup->setFrameStyle( QFrame::Plain | QFrame::Box );
     mGroup->setGeometry(140, yOff + 100, 230, 100);
     for( i = 0 ; i < 4 ; i++ ) {
 	name.sprintf("MetricsLabel[%i][%i]",i,0);
@@ -675,12 +677,11 @@ int main( int argc, char **argv )
 {
     QApplication a( argc, argv );
 
-//    QColor x( 0x41, 0xa2, 0xc3 );	// sea-green
-    QColor x( 0xaa, 0xbe, 0xff );	// kind of blue
+/*  QColor x( 0xaa, 0xbe, 0xff );	// kind of blue
     QColorGroup g( black, x, x.light(), x.dark(), x.dark(120),	black, white );
     QPalette p( g, g, g );
     a.setPalette( p );
-
+*/
     XFormCenter *xfc = new XFormCenter;
     xfc->setGeometry( 0, 0, 500, 400 );
     xfc->show();
