@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qbitmap.h,v 1.10 1995/05/07 18:29:16 hanord Exp $
+** $Id: qbitmap.h,v 1.11 1995/06/08 18:21:21 eiriken Exp $
 **
 ** Definition of QBitmap class
 **
@@ -20,8 +20,10 @@ class QBitmap : public QPixmap			// bitmap class
 {
 public:
     QBitmap();
-    QBitmap( int w, int h );
-    QBitmap( int w, int h, const char *bits, bool isXbitmap=FALSE );
+    QBitmap( int w, int h,    bool clear = FALSE );
+    QBitmap( const QSize &sz, bool clear = FALSE  );
+    QBitmap( int w, int h,    const char *bits, bool isXbitmap=FALSE );
+    QBitmap( const QSize &sz, const char *bits, bool isXbitmap=FALSE );
     QBitmap( const QBitmap & );
 
     QBitmap &operator=( const QBitmap & );
