@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qbttngrp.h,v 1.5 1995/05/19 23:15:33 eiriken Exp $
+** $Id: qbttngrp.h,v 1.7 1995/06/06 02:17:05 hanord Exp $
 **
 ** Definition of QButtonGroup class
 **
@@ -25,9 +25,10 @@ class QButtonGroup : public QGroupBox
     Q_OBJECT
 public:
     QButtonGroup( QWidget *parent=0, const char *name=0 );
+    QButtonGroup( const char *title, QWidget *parent=0, const char *name=0 );
    ~QButtonGroup();
 
-    void insert( QButton *, int id=-1 );
+    int  insert( QButton *, int id=-1 );
     void remove( QButton * );
 
 signals:
@@ -37,6 +38,7 @@ protected slots:
     void buttonClicked();
 
 private:
+    void	init();
     QButtonList *buttons;
 };
 
