@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qdialog.h,v 1.4 1995/05/14 17:57:23 eiriken Exp $
+** $Id: qdialog.h,v 1.5 1995/06/05 21:12:49 hanord Exp $
 **
 ** Definition of QDialog class
 **
@@ -16,8 +16,12 @@
 #include "qview.h"
 
 
+class QPushButton;
+
+
 class QDialog : public QView			// modal dialog widget
 {
+friend class QPushButton;
     Q_OBJECT
 public:
     QDialog( QWidget *parent=0, const char *name=0, WFlags f=WType_Modal );
@@ -48,6 +52,7 @@ protected:
     void	keyPressEvent( QKeyEvent * );
 
 private:
+    void	setDefault( QPushButton * );
     int		rescode;
     uint	did_move   : 1;
     uint	did_resize : 1;
