@@ -1,5 +1,5 @@
 /**********************************************************************
-** $Id: qgrpbox.h,v 1.3 1995/05/14 21:34:49 hanord Exp $
+** $Id: qgrpbox.h,v 1.4 1995/06/05 19:27:26 hanord Exp $
 **
 ** Definition of QGroupBox widget class
 **
@@ -21,6 +21,7 @@ class QGroupBox : public QFrame
     Q_OBJECT
 public:
     QGroupBox( QWidget *parent=0, const char *name=0 );
+    QGroupBox( const char *title, QWidget *parent=0, const char *name=0 );
 
     const char *title()		const	{ return str; }
 
@@ -33,6 +34,7 @@ protected:
     void	paintEvent( QPaintEvent * );
 
 private:
+    void	init();
     QString	str;
     int		align;
 };
