@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qpushbt.h,v 1.13 1995/05/19 23:15:33 eiriken Exp $
+** $Id: qpushbt.h,v 1.15 1995/06/06 02:00:49 hanord Exp $
 **
 ** Definition of QPushButton class
 **
@@ -18,6 +18,7 @@
 
 class QPushButton : public QButton
 {
+friend class QDialog;
     Q_OBJECT
 public:
     QPushButton( QWidget *parent=0, const char *name=0 );
@@ -39,9 +40,6 @@ public:
     void	setGeometry( int x, int y, int w, int h );
     void	setGeometry( const QRect & );
 
-signals:
-    void	becameDefault();
-
 protected:
     void	drawButton( QPainter * );
     virtual void drawButtonFace( QPainter * );
@@ -49,10 +47,10 @@ protected:
 private:
     void	init();
 
-    uint	autoDefButton : 1;
-    uint	defButton	  : 1;
-    uint	lastDown	  : 1;
-    uint	lastDef	  : 1;
+    uint	autoDefButton	: 1;
+    uint	defButton	: 1;
+    uint	lastDown	: 1;
+    uint	lastDef		: 1;
 };
 
 
